# DeviceState


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**deleted** | **datetime** |  | [optional] [readonly] 
**status** | [**StatusEnum**](StatusEnum.md) |  | [optional] 
**command** | [**DeviceStateCommandEnum**](DeviceStateCommandEnum.md) |  | [optional] 
**ansible_facts** | **dict(str, object)** |  | [optional] 
**ansible_extra_vars** | **dict(str, object)** |  | [optional] 
**created_dt** | **datetime** |  | [optional] [readonly] 
**device** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


